%define upstream_name    File-FcntlLock
%define upstream_version 0.22

%{?perl_default_filter}

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 19

Summary:    File locking with fcntl()
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module/File/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(Carp)
BuildRequires: perl(DynaLoader)
BuildRequires: perl(Errno)
BuildRequires: perl(Exporter)
BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(POSIX)
BuildRequires: perl-devel
%description
File locking in Perl is usually done using the the flock() manpage
function. Unfortunately, this only allows locks on whole files and is often
implemented in terms of the flock(2) manpage, which has some shortcomings.

Using this module file locking via the fcntl(2) manpage can be done
(obviously, this restricts the use of the module to systems that have a the
fcntl(2) manpage system call). Before a file (or parts of a file) can be
locked, an object simulating a flock structure must be created and its
properties set. Afterwards, by calling the 'lock()' method a lock can be
set or it can be determined if and which process currently holds the lock.

To create a new object representing a flock structure call 'new()':

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor

%{make}

%check
%{make} test

%install
%make_install

%files
%doc Changes META.yml README
%{_mandir}/man3/*
%perl_vendorarch/*


%changelog
* Tue Nov 28 2023 tv <tv> 0.220.0-19.mga10
+ Revision: 2010581
- Rebuild for perl-5.38

* Tue Jun 07 2022 umeabot <umeabot> 0.220.0-18.mga9
+ Revision: 1861897
- Rebuild for Perl 5.36

* Thu Mar 17 2022 umeabot <umeabot> 0.220.0-17.mga9
+ Revision: 1795733
- Mageia 9 Mass Rebuild

* Mon May 24 2021 umeabot <umeabot> 0.220.0-16.mga9
+ Revision: 1726583
- Rebuild for perl 5.34

* Wed Jun 17 2020 umeabot <umeabot> 0.220.0-15.mga8
+ Revision: 1594784
- Rebuild for perl 5.32

* Sun Feb 16 2020 umeabot <umeabot> 0.220.0-14.mga8
+ Revision: 1529464
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%makeinstall_std

* Tue Aug 27 2019 tmb <tmb> 0.220.0-13.mga8
+ Revision: 1433602
- rebuild for perl 5.30

* Fri Sep 21 2018 umeabot <umeabot> 0.220.0-12.mga7
+ Revision: 1292842
- Mageia 7 Mass Rebuild

* Wed Aug 08 2018 pterjan <pterjan> 0.220.0-11.mga7
+ Revision: 1250303
- Rebuild for perl 5.28

* Mon Oct 02 2017 tv <tv> 0.220.0-10.mga7
+ Revision: 1164317
- rebuild with fixed rpm for missing autodeps

* Thu Aug 31 2017 pterjan <pterjan> 0.220.0-9.mga7
+ Revision: 1148882
- Rebuild for perl ABI changes

* Sat Jul 22 2017 neoclust <neoclust> 0.220.0-8.mga7
+ Revision: 1126496
- Rebuild against new Perl 5.26

* Sun Jun 19 2016 pterjan <pterjan> 0.220.0-7.mga6
+ Revision: 1027295
- Rebuild for perl 5.22.2

* Fri Feb 12 2016 umeabot <umeabot> 0.220.0-6.mga6
+ Revision: 957275
- Mageia 6 Mass Rebuild

* Thu Jun 25 2015 sander85 <sander85> 0.220.0-5.mga6
+ Revision: 843561
- Rebuild for perl 5.22

* Sun Oct 19 2014 umeabot <umeabot> 0.220.0-4.mga5
+ Revision: 789709
- Rebuild to potentially add missing dependencies

* Wed Oct 15 2014 umeabot <umeabot> 0.220.0-3.mga5
+ Revision: 747736
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.220.0-2.mga5
+ Revision: 684719
- Mageia 5 Mass Rebuild

* Fri Aug 01 2014 sander85 <sander85> 0.220.0-1.mga5
+ Revision: 658985
- update to 0.22

* Tue Jun 03 2014 pterjan <pterjan> 0.200.0-2.mga5
+ Revision: 631180
- Rebuild for perl 5.20

* Tue May 27 2014 sander85 <sander85> 0.200.0-1.mga5
+ Revision: 627069
- update to 0.20

* Tue May 27 2014 sander85 <sander85> 0.190.0-1.mga5
+ Revision: 626965
- update to 0.19
- update to 0.16

* Sat Oct 19 2013 umeabot <umeabot> 0.140.0-5.mga4
+ Revision: 524759
- Mageia 4 Mass Rebuild

* Wed May 29 2013 jquelin <jquelin> 0.140.0-4.mga4
+ Revision: 431517
- perl 5.18.0 rebuild

* Sun Jan 13 2013 umeabot <umeabot> 0.140.0-3.mga3
+ Revision: 367180
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed May 30 2012 jquelin <jquelin> 0.140.0-2.mga3
+ Revision: 250624
- rebuild for perl 5.16

* Wed Nov 09 2011 jquelin <jquelin> 0.140.0-1.mga2
+ Revision: 165776
- do not ship MYMETA
- update to 0.14

* Thu Oct 13 2011 jquelin <jquelin> 0.130.0-1.mga2
+ Revision: 154293
- update to 0.13

* Sun Jun 12 2011 sander85 <sander85> 0.120.0-4.mga2
+ Revision: 104267
- perl 5.14

* Fri Jan 21 2011 jquelin <jquelin> 0.120.0-3.mga1
+ Revision: 30288
- mageia rebuild
- imported package perl-File-FcntlLock

